==> customized-facade-1.0.3-20200320.060229-99-sources.jar: com/bizvane/customized/facade/models/po/CusUrMbrGiftCardPO.java <==
package com.bizvane.customized.facade.models.po;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.Objects;

public class CusUrMbrGiftCardPO implements Serializable {

	/**
	 * 只读. 自增主键. gift_card_id
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	@io.swagger.annotations.ApiModelProperty(value = "自增主键", name = "giftCardId", required = false, example = "")
	private Long giftCardId;
	/**
	 * 只读. 所属企业id. sys_company_id
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	@io.swagger.annotations.ApiModelProperty(value = "所属企业id", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. 所属品牌id. sys_brand_id
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	@io.swagger.annotations.ApiModelProperty(value = "所属品牌id", name = "sysBrandId", required = false, example = "")
	private Long sysBrandId;
	/**
	 * 只读. 任务批次号. task_batch_code
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	@io.swagger.annotations.ApiModelProperty(value = "任务批次号", name = "taskBatchCode", required = false, example = "")
	private String taskBatchCode;
	/**
	 * 只读. 任务名称. task_file_name
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	@io.swagger.annotations.ApiModelProperty(value = "任务名称", name = "taskFileName", required = false, example = "")
	private String taskFileName;
	/**
	 * 只读. 卡号. card_no
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	@io.swagger.annotations.ApiModelProperty(value = "卡号", name = "cardNo", required = false, example = "")
	private String cardNo;
	/**
	 * 只读. 密码. password
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	@io.swagger.annotations.ApiModelProperty(value = "密码", name = "password", required = false, example = "")
	private String password;
	/**
	 * 只读. 余额. balance
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	@io.swagger.annotations.ApiModelProperty(value = "余额", name = "balance", required = false, example = "")
	private BigDecimal balance;
	/**
	 * 只读. 激活状态：1未激活 2已激活 3已作废. status
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	@io.swagger.annotations.ApiModelProperty(value = "激活状态：1未激活 2已激活 3已作废", name = "status", required = false, example = "")
	private String status;
	/**
	 * 只读. 类型：1新增，2导入. type
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	@io.swagger.annotations.ApiModelProperty(value = "类型：1新增，2导入", name = "type", required = false, example = "")
	private String type;
	/**
	 * 只读. 有效期. validity_time
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	@io.swagger.annotations.ApiModelProperty(value = "有效期", name = "validityTime", required = false, example = "")
	private String validityTime;
	/**
	 * 只读. 创建人. creater
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人", name = "creater", required = false, example = "")
	private String creater;
	/**
	 * 只读. 创建日期. created_date
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建日期", name = "createdDate", required = false, example = "")
	private String createdDate;
	/**
	 * 只读. 数据有效性（1有效，0无效）. valid
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	@io.swagger.annotations.ApiModelProperty(value = "数据有效性（1有效，0无效）", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. 修改人id. modified_user_id
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. 修改人. modified_user_name
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. 修改时间 . modified_date
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改时间 ", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public Long getGiftCardId() {
		return giftCardId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public void setGiftCardId(Long giftCardId) {
		this.giftCardId = giftCardId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public Long getSysBrandId() {
		return sysBrandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public void setSysBrandId(Long sysBrandId) {
		this.sysBrandId = sysBrandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public String getTaskBatchCode() {
		return taskBatchCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public void setTaskBatchCode(String taskBatchCode) {
		this.taskBatchCode = taskBatchCode == null ? null : taskBatchCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public String getTaskFileName() {
		return taskFileName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public void setTaskFileName(String taskFileName) {
		this.taskFileName = taskFileName == null ? null : taskFileName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public String getCardNo() {
		return cardNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public void setCardNo(String cardNo) {
		this.cardNo = cardNo == null ? null : cardNo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public String getPassword() {
		return password;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public void setPassword(String password) {
		this.password = password == null ? null : password.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public BigDecimal getBalance() {
		return balance;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public void setBalance(BigDecimal balance) {
		this.balance = balance;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public String getStatus() {
		return status;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public void setStatus(String status) {
		this.status = status == null ? null : status.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public String getType() {
		return type;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public void setType(String type) {
		this.type = type == null ? null : type.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public String getValidityTime() {
		return validityTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public void setValidityTime(String validityTime) {
		this.validityTime = validityTime == null ? null : validityTime.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public String getCreater() {
		return creater;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public void setCreater(String creater) {
		this.creater = creater == null ? null : creater.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public String getCreatedDate() {
		return createdDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public void setCreatedDate(String createdDate) {
		this.createdDate = createdDate == null ? null : createdDate.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-26 09:54:18
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	@Override
	public boolean equals(Object o) {
		if (this == o) return true;
		if (o == null || getClass() != o.getClass()) return false;
		CusUrMbrGiftCardPO that = (CusUrMbrGiftCardPO) o;
		return Objects.equals(giftCardId, that.giftCardId) &&
				Objects.equals(sysCompanyId, that.sysCompanyId) &&
				Objects.equals(sysBrandId, that.sysBrandId) &&
				Objects.equals(cardNo, that.cardNo) &&
				Objects.equals(password, that.password) &&
				Objects.equals(balance, that.balance);
	}

	@Override
	public int hashCode() {
		return Objects.hash(giftCardId, sysCompanyId, sysBrandId, taskBatchCode, taskFileName, cardNo, password, balance, status, type, validityTime, creater, createdDate, valid, modifiedUserId, modifiedUserName, modifiedDate);
	}
}

==> customized-facade-20250115-20250116.072810-5-sources.jar: com/bizvane/customized/facade/models/po/CusUrMbrGiftCardPO.java <==
package com.bizvane.customized.facade.models.po;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.Objects;
import io.swagger.annotations.ApiModelProperty;

public class CusUrMbrGiftCardPO implements Serializable {

	/**
	 * 只读. 自增主键. gift_card_id
	 * @mbg.generated
	 */
	@ApiModelProperty(value = "自增主键", name = "giftCardId")
	private Long giftCardId;
	/**
	 * 只读. 所属企业id. sys_company_id
	 * @mbg.generated
	 */
	@ApiModelProperty(value = "所属企业id", name = "sysCompanyId")
	private Long sysCompanyId;
	/**
	 * 只读. 所属品牌id. sys_brand_id
	 * @mbg.generated
	 */
	@ApiModelProperty(value = "所属品牌id", name = "sysBrandId")
	private Long sysBrandId;
	/**
	 * 只读. 任务批次号. task_batch_code
	 * @mbg.generated
	 */
	@ApiModelProperty(value = "任务批次号", name = "taskBatchCode")
	private String taskBatchCode;
	/**
	 * 只读. 任务名称. task_file_name
	 * @mbg.generated
	 */
	@ApiModelProperty(value = "任务名称", name = "taskFileName")
	private String taskFileName;
	/**
	 * 只读. 卡号. card_no
	 * @mbg.generated
	 */
	@ApiModelProperty(value = "卡号", name = "cardNo")
	private String cardNo;
	/**
	 * 只读. 密码. password
	 * @mbg.generated
	 */
	@ApiModelProperty(value = "密码", name = "password")
	private String password;
	/**
	 * 只读. 余额(不含赠送部分). balance
	 * @mbg.generated
	 */
	@ApiModelProperty(value = "余额(不含赠送部分)", name = "balance")
	private BigDecimal balance;
	/**
	 * 只读. 赠送金额. give_balance
	 * @mbg.generated
	 */
	@ApiModelProperty(value = "赠送金额", name = "giveBalance")
	private BigDecimal giveBalance;
	/**
	 * 只读. 激活状态：1未激活 2已激活 3已作废. status
	 * @mbg.generated
	 */
	@ApiModelProperty(value = "激活状态：1未激活 2已激活 3已作废", name = "status")
	private String status;
	/**
	 * 只读. 类型：1新增，2导入. type
	 * @mbg.generated
	 */
	@ApiModelProperty(value = "类型：1新增，2导入", name = "type")
	private String type;
	/**
	 * 只读. 有效期. validity_time
	 * @mbg.generated
	 */
	@ApiModelProperty(value = "有效期", name = "validityTime")
	private String validityTime;
	/**
	 * 只读. 创建人. creater
	 * @mbg.generated
	 */
	@ApiModelProperty(value = "创建人", name = "creater")
	private String creater;
	/**
	 * 只读. 创建日期. created_date
	 * @mbg.generated
	 */
	@ApiModelProperty(value = "创建日期", name = "createdDate")
	private String createdDate;
	/**
	 * 只读. 数据有效性（1有效，0无效）. valid
	 * @mbg.generated
	 */
	@ApiModelProperty(value = "数据有效性（1有效，0无效）", name = "valid")
	private Boolean valid;
	/**
	 * 只读. 修改人id. modified_user_id
	 * @mbg.generated
	 */
	@ApiModelProperty(value = "修改人id", name = "modifiedUserId")
	private Long modifiedUserId;
	/**
	 * 只读. 修改人. modified_user_name
	 * @mbg.generated
	 */
	@ApiModelProperty(value = "修改人", name = "modifiedUserName")
	private String modifiedUserName;
	/**
	 * 只读. 修改时间 . modified_date
	 * @mbg.generated
	 */
	@ApiModelProperty(value = "修改时间 ", name = "modifiedDate")
	private Date modifiedDate;
	/**
	 * 只读. 
	 * @mbg.generated
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public Long getGiftCardId() {
		return giftCardId;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public void setGiftCardId(Long giftCardId) {
		this.giftCardId = giftCardId;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public Long getSysBrandId() {
		return sysBrandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public void setSysBrandId(Long sysBrandId) {
		this.sysBrandId = sysBrandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public String getTaskBatchCode() {
		return taskBatchCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public void setTaskBatchCode(String taskBatchCode) {
		this.taskBatchCode = taskBatchCode == null ? null : taskBatchCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public String getTaskFileName() {
		return taskFileName;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public void setTaskFileName(String taskFileName) {
		this.taskFileName = taskFileName == null ? null : taskFileName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public String getCardNo() {
		return cardNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public void setCardNo(String cardNo) {
		this.cardNo = cardNo == null ? null : cardNo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public String getPassword() {
		return password;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public void setPassword(String password) {
		this.password = password == null ? null : password.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public BigDecimal getBalance() {
		return balance;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public void setBalance(BigDecimal balance) {
		this.balance = balance;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public BigDecimal getGiveBalance() {
		return giveBalance;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public void setGiveBalance(BigDecimal giveBalance) {
		this.giveBalance = giveBalance;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public String getStatus() {
		return status;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public void setStatus(String status) {
		this.status = status == null ? null : status.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public String getType() {
		return type;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public void setType(String type) {
		this.type = type == null ? null : type.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public String getValidityTime() {
		return validityTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public void setValidityTime(String validityTime) {
		this.validityTime = validityTime == null ? null : validityTime.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public String getCreater() {
		return creater;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public void setCreater(String creater) {
		this.creater = creater == null ? null : creater.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public String getCreatedDate() {
		return createdDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public void setCreatedDate(String createdDate) {
		this.createdDate = createdDate == null ? null : createdDate.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	@Override
	public boolean equals(Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		CusUrMbrGiftCardPO that = (CusUrMbrGiftCardPO) o;
		return Objects.equals(giftCardId, that.giftCardId) &&
				Objects.equals(sysCompanyId, that.sysCompanyId) &&
				Objects.equals(sysBrandId, that.sysBrandId) &&
				Objects.equals(cardNo, that.cardNo) &&
				Objects.equals(password, that.password) &&
				Objects.equals(balance, that.balance);
	}

	@Override
	public int hashCode() {
		return Objects.hash(giftCardId, sysCompanyId, sysBrandId, taskBatchCode, taskFileName, cardNo, password, balance, status, type, validityTime, creater, createdDate, valid, modifiedUserId, modifiedUserName, modifiedDate);
	}
}
